<!--机组风向-->
<template>
    <div class="fullheight">
        <ht-table
            @load="loadData"
            @row-dblclick="(row) => showDialog(row.id)"
            :data="data"
            :pageResult="pageResult"
            :selection="true"
            quick-search-props="windDirection"
            :default-sorter="[{direction: 'ASC', property: 'sn'}]"
            :show-export="false"
            :show-custom-column="false"
            ref="htTable"
        >
            <template v-slot:toolbar>
                <el-button
                    size="small"
                    type="primary"
                    @click="showDialog()"
                    icon="el-icon-plus"
                    >添加</el-button
                >
                <ht-delete-button
                    url="${cssc}/biz/cqkz/windFan/v1/"
                    :htTable="$refs.htTable"
                    >删除</ht-delete-button
                >
                <el-button
                    size="small"
                    type="primary"
                    plain
                    @click="saveSn"
                    icon="el-icon-finished"
                    >保存排序号</el-button
                >
            </template>
            <template>
                <ht-table-column
                    prop="windDirection"
                    label="风向"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="fanList"
                    label="机组编码"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="fanNameList"
                    label="机组名称"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="fanNum"
                    label="机组数量"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="sn"
                    label="排序号"
                    width="120"
                    :sortable="true"
                >
                    <template v-slot="{row}">
                        <el-input-number
                            style="width: 100%"
                            v-model="row.sn"
                            :controls="false"
                            @change="(val) => handleChangeSn(row, val)"
                            :min="0"
                        ></el-input-number>
                    </template>
                </ht-table-column>
            </template>
        </ht-table>
        <common-dialog
            width="800px"
            title="机组基础信息"
            class="sp-manager__dialog"
            :visible="dialogVisible"
            :before-close="beforeCloseDialog"
            destroy-on-close
        >
            <el-form
                v-model="params"
                data-vv-scope="paramsForm"
                clsss="fan-info-form"
            >
                <el-row :gutter="10">
                    <el-col :span="12">
                        <ht-form-item label="风向/ °" prop="windDirection">
                            <ht-input
                                class="number-type"
                                type="number"
                                :min="0"
                                :max="360"
                                v-model="params.windDirection"
                                validate="required"
                            />
                            <span> °</span>
                        </ht-form-item>
                    </el-col>
                    <el-col :span="12">
                        <ht-form-item label="机组数量" prop="fanNum">
                            <ht-input
                                class="number-type"
                                v-model="params.fanNum"
                                type="number"
                                :min="0"
                                disabled
                            />
                            <span> 个</span>
                        </ht-form-item>
                    </el-col>
                </el-row>
                <el-row :gutter="10">
                    <el-col :span="24">
                        <ht-form-item label="机组名称" prop="fanList">
                            <ht-select
                                style="width: 98%"
                                v-model="params.fanList"
                                validate="required"
                                multiple
                                :options="crewList"
                                :props="{key: 'fanCode', value: 'fanName'}"
                                @change="changeCrewList"
                            ></ht-select>
                        </ht-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <div slot="footer" style="text-align: center">
                <ht-submit-button
                    url="${cssc}/biz/cqkz/windFan/v1/"
                    :model="params"
                    :request-method="saveMethod"
                    scope-name="paramsForm"
                    @after-save-data="afterSaveData"
                    >保存</ht-submit-button
                >
                <el-button @click="beforeCloseDialog">取消</el-button>
            </div>
        </common-dialog>
    </div>
</template>
<script>
import CommonDialog from '../../components/dialog/CommonDialog.vue'

export default {
    name: 'CrewWind',
    components: {CommonDialog},
    data() {
        return {
            dialogVisible: false,
            data: [],
            pageResult: {
                page: 1,
                pageSize: 50,
                total: 0,
            },
            params: {
                fanNum: 0,
                fanList: '',
                fanNameList: '',
                windDirection: '',
            },
            saveMethod: 'POST',
            crewList: [],
            snObj: {},
        }
    },
    mounted() {
        this.$validator = this.$root.$validator
    },
    created() {
        this.getCrewList()
    },
    methods: {
        handleChangeSn(row, val) {
            this.snObj[row.id] = val
        },
        saveSn() {
            this.$http
                .post('${cssc}/biz/cqkz/windFan/v1/updateSequence', this.snObj)
                .then((res) => {
                    this.$refs.htTable.load()
                })
        },
        changeCrewList(keys) {
            console.log(keys)
            let fanNames = ''
            for (let i = 0; i <= keys.length - 1; i++) {
                this.crewList.find((item) => {
                    if (item.fanCode == keys[i]) {
                        fanNames += item.fanName + ','
                    }
                })
            }
            this.params.fanNameList = fanNames.slice(0, fanNames.length - 1)
            console.log(this.params)
            this.params.fanNum = keys.length
        },
        getCrewList() {
            this.$http
                .post('${cssc}/biz/base/fanInfo/v1/list', {
                    sorter: [{direction: 'ASC', property: 'sn'}],
                })
                .then((res) => {
                    this.crewList = res.data
                })
        },
        showDialog(id) {
            if (id) {
                this.saveMethod = 'PUT'
                this.$http.get('${cssc}/biz/cqkz/windFan/v1/' + id).then(
                    (resp) => {
                        this.params = resp.data
                        this.dialogVisible = true
                    },
                    (error) => {
                        reject(error)
                    }
                )
            } else {
                this.saveMethod = 'POST'
                this.dialogVisible = true
            }
        },
        beforeCloseDialog() {
            this.params = {
                fanNum: 0,
                // fanListShow: [],
                fanList: '',
                fanNameList: '',
                windDirection: '',
            }
            this.dialogVisible = false
        },
        loadData(param, cb) {
            console.log(param, 'param')
            param.sorter = [{direction: 'ASC', property: 'sn_'}]
            this.$http
                .post('${cssc}/biz/cqkz/windFan/v1/query', param)
                .then(
                    (resp) => {
                        let response = resp.data
                        this.data = response.rows
                        this.pageResult = {
                            page: response.page,
                            pageSize: response.pageSize,
                            total: response.total,
                        }
                    },
                    (error) => {
                        reject(error)
                    }
                )
                .finally(() => cb())
        },
        afterSaveData() {
            setTimeout(() => {
                this.beforeCloseDialog()
                this.$refs.htTable.load()
            }, 500)
        },
    },
}
</script>
<style lang="scss" scoped>
.number-type /deep/ .el-input-number {
  width: 100%;
}
</style>
